starcluster.clustersetup.ClusterSetup

Package starcluster :: Module clustersetup :: Class ClusterSetup |
[hide private]
[frames] | no frames]

# Class ClusterSetup

source code

ClusterSetup Interface

This is the base class for all StarCluster plugins. A plugin should implement at least one if not all of these methods.

Instance Methods | [hide private]
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
on_add_node(self, node, nodes, master, user, user_shell, volumes) This methods gets executed after a node has been added to the cluster | source code
on_remove_node(self, node, nodes, master, user, user_shell, volumes) This method gets executed before a node is about to be removed from the cluster | source code
on_restart(self, nodes, master, user, user_shell, volumes) This method gets executed before restart the cluster | source code
on_shutdown(self, nodes, master, user, user_shell, volumes) This method gets executed before shutting down the cluster | source code
run(self, nodes, master, user, user_shell, volumes) Run this plugin's setup routines | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self, nodes, master, user, user_shell, volumes) | source code
Run this plugin's setup routines This method gets executed after the default cluster setup routines have been performed